<?php

namespace Drupal\testsuite;

use Drupal\Core\File\FileSystemInterface;

/**
 * Test Suite Base Service.
 */
class BaseService {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a new BaseService.
   *
   * @param \Drupal\Core\File\FileSystemInterface $fileSystem
   *   The file system interface.
   */
  public function __construct(FileSystemInterface $fileSystem) {
    $this->fileSystem = $fileSystem;
  }

  /**
   * Gets the initial data from a phpunit statement.
   *
   * @param string $statement
   *   The statement used in Phpunit to call tests from the CMD.
   *
   * @return string
   *   The data pulled with shell_exec.
   */
  protected function getData($statement) {
    $old_path = getcwd();

    if (preg_match('/\bweb\b/', $this->fileSystem->realpath('core'))) {
      $rootPath = dirname(dirname($this->fileSystem->realpath('core')));
    }
    else {
      $rootPath = dirname($this->fileSystem->realpath('core'));
    }

    chdir($rootPath);
    $results = shell_exec($statement);
    chdir($old_path);
    return $results;
  }

  /**
   * Checks to see if the path is windows.
   *
   * @return bool
   *   Returns true or false
   */
  public function isWindows() {
    return strtoupper(substr(PHP_OS, 0, 3)) === 'WIN';
  }

  /**
   * Builds a list of modules in an area.
   *
   * @param string $path
   *   The absolute path to where the modules are.
   *
   * @return array
   *   The array of modules.
   */
  public function getModulesByArea($path) {
    $modulesArray = [];
    if (is_dir($path)) {
      $scan = scandir($path);
      unset($scan[array_search('.', $scan, TRUE)]);
      unset($scan[array_search('..', $scan, TRUE)]);
      foreach ($scan as $module) {
        if (is_dir("$path/$module")) {
          $modulesArray[$module] = ucfirst(implode(" ", explode("_", $module)));
        }
      }
    }
    return $modulesArray;
  }

}
