<?php

namespace Drupal\testsuite;

use Drupal\Component\Utility\Xss;

/**
 * Test Suite Base Trait.
 */
trait BaseTrait {

  /**
   * The list of areas represent the areas where modules are.
   *
   * @var array
   */
  protected $areas = [
    'core',
    'contrib',
    'custom',
  ];

  /**
   * The list of directories represent the directories where phpunit tests are.
   *
   * @var array
   */
  protected $directories = [
    'Unit',
    'Kernel',
    'Functional',
    'FunctionalJavascript',
  ];

  /**
   * Formats the message.
   *
   * @param string $message
   *   The error report message.
   *
   * @return string|bool
   *   The message formated or FALSE.
   */
  protected function formatMessage($message) {
    if ($message != NULL) {
      $newMessage = str_replace("\n\n\n", "<br />", $message);
      $newMessage = str_replace("\n\n", "<br />", $newMessage);
      $newMessage = str_replace("\n", "<br />", $newMessage);
      return Xss::filterAdmin($newMessage);
    }
    else {
      return FALSE;
    }
  }

  /**
   * Takes the full file path and returns the file name.
   *
   * @param string $filePath
   *   The file we are reporting on.
   *
   * @return string
   *   The filename.
   */
  protected function getFileName($filePath) {
    if (preg_match('/\([^)]*\)/', $filePath)) {
      $fileParts = preg_split('/\s\(/', $filePath);
      $filePath = $fileParts[0];
    }
    $filePart = explode(DIRECTORY_SEPARATOR, $filePath);
    if (isset($fileParts[1])) {
      return end($filePart) . " (" . $fileParts[1];
    }
    else {
      return end($filePart);
    }

  }

}
