<?php

namespace Drupal\testsuite\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Returns responses for test reports routes.
 */
class TestSuiteController extends ControllerBase {

  /**
   * Landing page for custom tests.
   *
   * @return array
   *   The page as a render array.
   */
  public function landingPage() {
    $build['security-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => 'security-wrapper',
      ],
    ];

    $build['secure-form-fields-and-route-parameters'] = [
      '#type' => 'markup',
      '#markup' => '<p><b>This is not a full list. Please review <a href="https://www.drupal.org/docs/7/security/writing-secure-code" target="_blank">Writing Secure Code</a> and <a href="https://www.drupal.org/docs/administering-a-drupal-site/security-in-drupal/writing-secure-code-for-drupal" target="_blank">Writing secure code for Drupal</a> for more.</b></p><h3>Sanitize all user-supplied data.</h3><p>Input sanitization is the process of cleaning and validating user-supplied data before using it in your application. This ensures that the data is safe and free from any potential harm, such as code injections or other security vulnerabilities. Absolutely do not publish a release until you are sure you are done with all security on your module. Make sure all form fields and parameters that might open up a vulnerability are sanitized.</p>',
    ];
    $build['object-oriented-programming'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Use OOP (Object-Oriented Programming).</h3><p>Encapsulate data in classes using private methods and properties when ever possible. Use getters and setter to access properties and only use public methods when you have to. Use Inheritance, Traits and Dependency Injection to connect classes and use them in your code. When you can if you need access other than private try to use protected. Try to avoid using static methods and properties when possible. Avoid static calls to \Drupal:: and use DI.</p>',
    ];
    $build['give-extra-care-eval-shellexec'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Give extra care when using shell_exec(), exec(), eval() etc..</h3><p>Methods that execute code are an even bigger security risk. Try to put them in an inherited class in a protected method or in a private method of the calling class and make sure nothing but what you want passes to it gets passed to it. Be carefull to sanitize all parameters that get passed to the calling method.</p>',
    ];
    $build['escape-all-sql-parameters'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Escape all SQL parameters.</h3><p><a href="https://www.drupal.org/docs/7/security/writing-secure-code/database-access" target="_blank">Mysql Injection</a> happens when you fail to escape user-supplied data as a parameter to an raw SQL query.</p>',
    ];
    $build['use-code-checkers'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Use Phpcs and Phpstan.</h3><p>Validate your code with packages like Phpcs and Phpstan. Although alot of the results are related to spacing, line indentation and code beautification, errors in your code get spotted too.</p>',
    ];
    $build['xss-attacks'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Filter database data for <a href="https://www.drupal.org/docs/administering-a-drupal-site/security-in-drupal/writing-secure-code-for-drupal" target="_blank">Xss</a>.</h3><p>When handling data, the golden rule is to store exactly what the user typed. When a user edits a post they created earlier, the form should contain the same things as it did when they first submitted it (including any dangerous content they may have included). This means that conversions are performed when content is output, not when saved to the database (be sure to read the db_query() documentation on how to use the database API securely).</p><p>If you want special formating use Drupal\Component\Utility\Xss::filterAdmin($string) to filter the data when you pull it from the database before you put it on the page. It applies a very permissive XSS/HTML filter for admin-only use and allows all tags that can be used inside an HTML body, save for scripts and styles.</p>',
    ];

    return $build;
  }

}
